@@ -8,7 +8,7 @@ from __future__ import annotations
 
 # version_info: same semantics as sys.version_info.
 # _dev: the .devN suffix if any.
-version_info = (7, 6, 7, "final", 0)
+version_info = (7, 11, 1, "final", 0)
 _dev = 0
 
 
@@ -22,7 +22,7 @@ def _make_version(
 ) -> str:
     """Create a readable version string from version_info tuple components."""
     assert releaselevel in ["alpha", "beta", "candidate", "final"]
-    version = "%d.%d.%d" % (major, minor, micro)
+    version = f"{major}.{minor}.{micro}"
     if releaselevel != "final":
         short = {"alpha": "a", "beta": "b", "candidate": "rc"}[releaselevel]
         version += f"{short}{serial}"
@@ -31,20 +31,5 @@ def _make_version(
     return version
 
 
-def _make_url(
-    major: int,
-    minor: int,
-    micro: int,
-    releaselevel: str,
-    serial: int = 0,
-    dev: int = 0,
-) -> str:
-    """Make the URL people should start at for this version of coverage.py."""
-    return (
-        "https://coverage.readthedocs.io/en/"
-        + _make_version(major, minor, micro, releaselevel, serial, dev)
-    )
-
-
 __version__ = _make_version(*version_info, _dev)
-__url__ = _make_url(*version_info, _dev)
+__url__ = f"https://coverage.readthedocs.io/en/{__version__}"
